pub enum Kind {
Feeding,
Medication,
Medical,
Behavior,
Grooming,
Training,
General,
}Expand description
Care-note category used to route safety, feeding, medication, behavior, and staff handoff information.
Variants
Feeding
Feeding state or source category preserved for normalized resort records.
Medication
Medication state or source category preserved for normalized resort records.
Medical
Medical state or source category preserved for normalized resort records.
Behavior
Behavior state or source category preserved for normalized resort records.
Grooming
Grooming service line or care-note category.
Training
Training service line or care-note category.
General
General state or source category preserved for normalized resort records.